==> driza-0.6.1.tar.gz: driza-0.6.1/Driza/vsalida.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#vsalida.py: Ventana que muestra los resultados de las operaciones solicitadas

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#self.archivoAbrirAction
#self.archivoGuardarAction
#self.archivoGuardar_comoAction
#self.exportarAction
#self.toolbar: toolbar
#self.texBrowser1: Zona que muestra contenido html

from Driza.ui.ventanas.uivsalida import VentanaSalida
from qt import *

class VSalida(VentanaSalida):
	"""Ventana que muestra los resultados de las operaciones solicitadas. Permite al usuario exportar o guardar los resultados ya obtenidos"""
	def __init__(self,parent,gestortemas):
		VentanaSalida.__init__(self)
		#VARIABLES PUBLICAS
		self.parent=parent
		#VARIABLES PRIVADAS
		self.__gestortemas=gestortemas
		self.__contenido = []

		self.__inittoolbar()
		self.__conexiones()

	#FUNCIONES PUBLICAS

	def appRes(self,objeto):
		"""Añade un resultado al dialogo, para ser mostrado"""
		self.__contenido.append(objeto)

	def show(self):
		"""Redefinicion del método show de VentanaSalida, muestra todos los resultados almacenados"""
		cadenasalida=""
		i=1
		for resultado in self.__contenido:
			cadenasalida+="<a name="+str(i)+"></a>"
			cadenasalida+=resultado.html().encode('ascii','replace')
			i+=1
		self.textBrowser1.setText(cadenasalida,"/tmp")
		self.textBrowser1.scrollToAnchor(str(len(self.__contenido)))
		VentanaSalida.show(self)

	def closeEvent( self, ev ):
		"""Acciones que se realizaran cuando el usuario cierre la ventana. Verifica si es la última ventana abierta"""
		if not self.parent.maindialog.isVisible():
			self.parent.quit()
		else:
			QWidget.closeEvent( self, ev )

	#FUNCIONES PRIVADAS

	def __conexiones(self):
		"""Bloque de conexiones"""
		self.connect(self.archivoAbrirAction,SIGNAL("activated()"),self.__dabrirfichero)
		self.connect(self.archivoGuardarAction,SIGNAL("activated()"),self.__dguardarfichero)
		self.connect(self.archivoExportarHTMLAction,SIGNAL("activated()"),self.__dexportar)
		self.connect(self.archivoSalirAction,SIGNAL("activated()"),self.__ocultar)
		self.connect(self.boton1,SIGNAL("clicked()"),self.__dabrirfichero)
		self.connect(self.boton2,SIGNAL("clicked()"),self.__dguardarfichero)
		self.connect(self.boton3,SIGNAL("clicked()"),self.__dexportar)

	def __inittoolbar(self):
		"""Inicializa la toolbar"""
		self.boton1=QToolButton(self.Toolbar)
		self.boton1.setTextLabel("ABRIR")
	 	iconos=QIconSet()
		iconos.setIconSize(QIconSet.Small,QSize(100,100))
		iconos.setPixmap(self.__gestortemas.iconoabrir(),QIconSet.Small)
		self.boton1.setOn(True)
		self.boton1.setIconSet(iconos)
		self.boton2=QToolButton(self.Toolbar)
		self.boton2.setTextLabel("GUARDAR")
	 	iconos=QIconSet()
		iconos.setIconSize(QIconSet.Small,QSize(100,100))
		iconos.setPixmap(self.__gestortemas.iconoguardar(),QIconSet.Small)
		self.boton2.setOn(True)
		self.boton2.setIconSet(iconos)
		self.boton3=QToolButton(self.Toolbar)
		self.boton3.setTextLabel("GUARDAR")
	 	iconos=QIconSet()
		iconos.setIconSize(QIconSet.Small,QSize(100,100))
		iconos.setPixmap(self.__gestortemas.iconoexportar(),QIconSet.Small)
		self.boton3.setOn(True)
		self.boton3.setIconSet(iconos)

	def __dabrirfichero(self):		
		"""Pregunta al usuario que fichero cargar"""
		import string
		filter=""
		for fmt in ["dro"]: #Candidata al fichero de listas
			filter=filter+"%s files (*.%s);;" % (fmt,string.lower(fmt))
		fn = QFileDialog.getOpenFileName(QString.null,filter,self,None,"Dialogo abrir fichero","")
		filename = str(fn)
		if filename:
			self.__cargarfichero(filename)

	def __cargarfichero(self,fichero):
		"""Carga un fichero"""
		import re
		regexp=re.compile('.*\.dro$')
		archivo = open(fichero, 'r')
		if regexp.match(fichero):
			import pickle
			self.__contenido=pickle.load(archivo)
		self.show()
	
	def __dguardarfichero(self):
		"""Pregunta al usuario en que fichero guardar"""
		import string
		filter=""
		for fmt in ["dro"]: #Candidata al fichero de listas
			filter=filter+"%s files (*.%s);;" % (fmt,string.lower(fmt))
		fn = QFileDialog.getSaveFileName(QString.null,filter,self)
		filename = str(fn)
		if filename:
			self.__guardarfichero(filename)

	def __guardarfichero(self,fichero):
		"""Guarda fichero"""
		import re
		regexp=re.compile('.*\.dro$')
		archivo = open(fichero, 'w')
		if regexp.match(fichero):
			import pickle
			pickle.dump(self.__contenido,archivo)
	
	def __dexportar(self):
		"""Pregunta al usuario en que fichero exportar"""
		import string
		filter=""
		for fmt in ["html"]: #Candidata al fichero de listas
			filter=filter+"%s files (*.%s);;" % (fmt,string.lower(fmt))
		fn = QFileDialog.getSaveFileName(QString.null,filter,self)
		filename = str(fn)
		if filename:
			self.__exportar(filename)

	def __exportar(self,fichero):
		"""Exporta un fichero a html"""
		import re
		regexp=re.compile('.*\.html$')
		if not regexp.match(fichero):
			fichero+=".html"
		archivo = open(fichero, 'w')
		import os
		cadenasalida=""
		#Obtenido de: http://xahlee.org/perl-python/split_fullpath.html
		(dirName, fileName) = os.path.split(fichero)
		(fileBaseName, fileExtension)=os.path.splitext(fileName)
		#TODO: Crear carpeta y pasar el nombre a exportarhtml
		os.mkdir(dirName+"/"+fileBaseName)
		for resultado in self.__contenido:
			ristra= resultado.exportarhtml(dirName+"/"+fileBaseName)
			print ristra
			archivo.write(ristra.encode('iso-8859-1', 'replace'))
		#archivo.write (cadenasalida)

	def __ocultar(self):
		"""Acciones que se realizaran cuando el usuario pulse salir. Verifica si es la última ventana abierta"""
		if not self.parent.maindialog.isVisible():
			self.parent.quit()
		else:
			self.hide()

==> driza-0.6.3.tar.gz: driza-0.6.3/Driza/vsalida.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#vsalida.py: Ventana que muestra los resultados de las operaciones solicitadas

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#self.archivoAbrirAction
#self.archivoGuardarAction
#self.archivoGuardar_comoAction
#self.exportarAction
#self.toolbar: toolbar
#self.texBrowser1: Zona que muestra contenido html

from Driza.ui.ventanas.uivsalida import VentanaSalida
from qt import *

class VSalida(VentanaSalida):
	"""Ventana que muestra los resultados de las operaciones solicitadas. Permite al usuario exportar o guardar los resultados ya obtenidos"""
	def __init__(self,parent,gestortemas):
		VentanaSalida.__init__(self)
		#VARIABLES PUBLICAS
		self.parent=parent
		#VARIABLES PRIVADAS
		self.__gestortemas=gestortemas
		self.__contenido = []

		self.__inittoolbar()
		self.__conexiones()

	#FUNCIONES PUBLICAS

	def appRes(self,objeto):
		"""Añade un resultado al dialogo, para ser mostrado"""
		self.__contenido.append(objeto)

	def myUpdate(self):
		cadenasalida=""
		i=1
		for resultado in self.__contenido:
			cadenasalida+="<a name="+str(i)+"></a>"
			cadenasalida+=resultado.html().encode('iso-8859-1','replace')
			i+=1
		self.textBrowser1.setText(cadenasalida,"/tmp")
		self.textBrowser1.scrollToAnchor(str(len(self.__contenido)))

	def showEvent(self,ev):
		"""Redefinicion del método show de VentanaSalida, muestra todos los resultados almacenados"""
		self.myUpdate()
		VentanaSalida.showEvent(self,ev)

	def closeEvent( self, ev ):
		"""Acciones que se realizaran cuando el usuario cierre la ventana. Verifica si es la última ventana abierta"""
		if not self.parent.maindialog.isVisible():
			self.parent.quit()
		else:
			QWidget.closeEvent( self, ev )

	#FUNCIONES PRIVADAS

	def __conexiones(self):
		"""Bloque de conexiones"""
		self.connect(self.archivoAbrirAction,SIGNAL("activated()"),self.__dabrirfichero)
		self.connect(self.archivoGuardarAction,SIGNAL("activated()"),self.__dguardarfichero)
		self.connect(self.archivoExportarHTMLAction,SIGNAL("activated()"),self.__dexportar)
		self.connect(self.archivoSalirAction,SIGNAL("activated()"),self.__ocultar)
		self.connect(self.boton1,SIGNAL("clicked()"),self.__dabrirfichero)
		self.connect(self.boton2,SIGNAL("clicked()"),self.__dguardarfichero)
		self.connect(self.boton3,SIGNAL("clicked()"),self.__dexportar)

	def __inittoolbar(self):
		"""Inicializa la toolbar"""
		self.boton1=QToolButton(self.Toolbar)
		self.boton1.setTextLabel("ABRIR")
	 	iconos=QIconSet()
		iconos.setIconSize(QIconSet.Small,QSize(100,100))
		iconos.setPixmap(self.__gestortemas.iconoabrir(),QIconSet.Small)
		self.boton1.setOn(True)
		self.boton1.setIconSet(iconos)
		self.boton2=QToolButton(self.Toolbar)
		self.boton2.setTextLabel("GUARDAR")
	 	iconos=QIconSet()
		iconos.setIconSize(QIconSet.Small,QSize(100,100))
		iconos.setPixmap(self.__gestortemas.iconoguardar(),QIconSet.Small)
		self.boton2.setOn(True)
		self.boton2.setIconSet(iconos)
		self.boton3=QToolButton(self.Toolbar)
		self.boton3.setTextLabel("GUARDAR")
	 	iconos=QIconSet()
		iconos.setIconSize(QIconSet.Small,QSize(100,100))
		iconos.setPixmap(self.__gestortemas.iconoexportar(),QIconSet.Small)
		self.boton3.setOn(True)
		self.boton3.setIconSet(iconos)

	def __dabrirfichero(self):		
		"""Pregunta al usuario que fichero cargar"""
		import string
		filter=""
		for fmt in ["dro"]: #Candidata al fichero de listas
			filter=filter+"%s files (*.%s);;" % (fmt,string.lower(fmt))
		fn = QFileDialog.getOpenFileName(QString.null,filter,self,None,"Dialogo abrir fichero","")
		filename = str(fn)
		if filename:
			self.__cargarfichero(filename)

	def __cargarfichero(self,fichero):
		"""Carga un fichero"""
		import re
		regexp=re.compile('.*\.dro$')
		archivo = open(fichero, 'r')
		if regexp.match(fichero):
			import pickle
			self.__contenido=pickle.load(archivo)
		self.myUpdate()
	
	def __dguardarfichero(self):
		"""Pregunta al usuario en que fichero guardar"""
		import string
		filter=""
		for fmt in ["dro"]: #Candidata al fichero de listas
			filter=filter+"%s files (*.%s);;" % (fmt,string.lower(fmt))
		fn = QFileDialog.getSaveFileName(QString.null,filter,self)
		filename = str(fn)
		if filename:
			self.__guardarfichero(filename)

	def __guardarfichero(self,fichero):
		"""Guarda fichero"""
		import re
		regexp=re.compile('.*\.dro$')
		archivo = open(fichero, 'w')
		if regexp.match(fichero):
			import pickle
			pickle.dump(self.__contenido,archivo)
	
	def __dexportar(self):
		"""Pregunta al usuario en que fichero exportar"""
		import string
		filter=""
		for fmt in ["html"]: #Candidata al fichero de listas
			filter=filter+"%s files (*.%s);;" % (fmt,string.lower(fmt))
		fn = QFileDialog.getSaveFileName(QString.null,filter,self)
		filename = str(fn)
		if filename:
			self.__exportar(filename)

	def __exportar(self,fichero):
		"""Exporta un fichero a html"""
		import re
		regexp=re.compile('.*\.html$')
		if not regexp.match(fichero):
			fichero+=".html"
		archivo = open(fichero, 'w')
		import os
		cadenasalida=""
		#Obtenido de: http://xahlee.org/perl-python/split_fullpath.html
		(dirName, fileName) = os.path.split(fichero)
		(fileBaseName, fileExtension)=os.path.splitext(fileName)
		#TODO: Crear carpeta y pasar el nombre a exportarhtml
		os.mkdir(dirName+"/"+fileBaseName)
		for resultado in self.__contenido:
			ristra= resultado.exportarhtml(dirName+"/"+fileBaseName)
			print ristra
			archivo.write(ristra.encode('iso-8859-1', 'replace'))
		#archivo.write (cadenasalida)

	def __ocultar(self):
		"""Acciones que se realizaran cuando el usuario pulse salir. Verifica si es la última ventana abierta"""
		if not self.parent.maindialog.isVisible():
			self.parent.quit()
		else:
			self.hide()
